// src/backend/concrete_process_statistics.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef CONCRETE_PROCESS_STATISTICS_HH
#define CONCRETE_PROCESS_STATISTICS_HH 1



#include <sgpemv2/process_statistics.hh>
#include <sgpemv2/thread_statistics.hh>
#include "concrete_thread_statistics.hh"


namespace sgpem
{
	class ConcreteStatistics;
	
	class ConcreteProcessStatistics : public ProcessStatistics 
	{
		public:
			friend class ConcreteStatistics;
			~ConcreteProcessStatistics ();
			
			int								get_execution_time() const;
			int								get_execution_progress() const;
			int								get_total_inactivity() const;
			int								get_response_time() const;
			float							get_average_response_time() const;
			int								get_turn_around() const;			
			int								get_efficiency() const;
			int								get_resource_usage_time() const;
			int								get_resource_waitings_time() const;
			
			const Process* 					get_core() const;
						
			std::vector<const ThreadStatistics*> 	get_threads_statistics() const;
		private:
			ConcreteProcessStatistics (const Process* core, const int& instant);
			
			const Process* 							_core;
			float									_average_response_time;
			std::vector<ConcreteThreadStatistics>	_threads_stats;
	};
}

#endif
