// src/backend/resource_policies_gatekeeper.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef RESOURCE_POLICIES_GATEKEEPER_HH
#define RESOURCE_POLICIES_GATEKEEPER_HH 1

namespace sgpem
{
  class ResourcePolicyManager;
  class ResourcePolicy;
  class History;
}

#include <sgpemv2/sgpemv2-visibility.hh>

#include <vector>
#include <map>
#include <stdexcept>

#include <sgpemv2/templates/singleton.hh>

namespace sgpem
{
  class ResourcePoliciesGatekeeper;

  /** \brief FIXME document me


   */

  class SG_DLLEXPORT ResourcePoliciesGatekeeper : public Singleton<ResourcePoliciesGatekeeper>
  {
    friend class Singleton<ResourcePoliciesGatekeeper>;

  public:
    typedef ResourcePolicyManager Manager;
    typedef std::vector<Manager*> Managers;

    const Managers&   get_registered() const;

    void       register_manager(ResourcePolicyManager* manager);

    void       unregister_manager(ResourcePolicyManager* manager);

    ResourcePolicy&   get_current_policy(History* history) throw(std::runtime_error);

    void       activate_policy(History* history, ResourcePolicy* policy);

  private:
    ResourcePoliciesGatekeeper();     //private constructor.
    ResourcePoliciesGatekeeper(const ResourcePoliciesGatekeeper&);
    ResourcePoliciesGatekeeper& operator=(const ResourcePoliciesGatekeeper&);

    void deactivate_policies(const ResourcePolicyManager& manager);

    Managers                                _registered;
    std::map<History*, ResourcePolicy*>     _active_policies;
  };

}//~ namespace sgpem

#endif //RESOURCE_POLICIES_GATEKEEPER_HH

