// src/holt_container_window.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef HOLT_CONTAINER_WINDOW_HH
#define HOLT_CONTAINER_WINDOW_HH 1


#include "gettext.h"

#include <gtkmm/window.h>

#include <cassert>
#include <iostream>

#include <sgpemv2/simulation.hh>
#include "cairo_widget.hh"
#include "holt_widget.hh"

namespace sgpem {
  // ------------------------------------------------------
  //
  // HoltContainerWindow class
  //
  // contains and controls the tested holt widget
  //
  // ------------------------------------------------------
  class HoltContainerWindow : public Gtk::Window
  {
  public:
    HoltContainerWindow(Simulation& simulation);
    virtual ~HoltContainerWindow();

    HoltWidget&   get_holt_widget();

  protected:
    virtual void  on_size_request (Gtk::Requisition* requisition);
    bool on_button_press_event(GdkEventButton* event);

    void set_disposition();

  private:
    void _on_dispose_vertical();
    void _on_dispose_circular();
    void _on_dispose_horizontal();
    void _on_dispose_auto();
    void _on_no_scaling();
    void _on_fit_scaling();


    HoltWidget    _holt_widget;
    bool          _auto_dispose;
  };

} // ~ namespace sgpem
#endif
